aboutsummaryrefslogtreecommitdiffhomepage
path: root/registry/reg.py
diff options
context:
space:
mode:
authorJon Leech <[email protected]>2021-03-21 20:23:34 -0700
committerJon Leech <[email protected]>2021-03-21 20:34:11 -0700
commita8d6ab19d197400be34422813c5edc7e4cbde552 (patch)
treef49f71090364b52dcee836c953d1d5935154a334 /registry/reg.py
parent89d366355e6fe1221c9be40bb2cf3716449e9a7e (diff)
downloadVulkan-Headers-a8d6ab19d197400be34422813c5edc7e4cbde552.tar.gz
Vulkan-Headers-a8d6ab19d197400be34422813c5edc7e4cbde552.zip
Update for Vulkan-Docs 1.2.173v1.2.173
Diffstat (limited to 'registry/reg.py')
-rw-r--r--registry/reg.py12
1 files changed, 9 insertions, 3 deletions
diff --git a/registry/reg.py b/registry/reg.py
index 5ed7c29..afb374d 100644
--- a/registry/reg.py
+++ b/registry/reg.py
@@ -1244,10 +1244,16 @@ class Registry:
# the regexp specified in the generator options. This allows
# forcing extensions into an interface even if they're not
# tagged appropriately in the registry.
+ # However we still respect the 'supported' attribute.
if regAddExtensions.match(extName) is not None:
- self.gen.logMsg('diag', 'Including extension',
- extName, '(matches explicitly requested extensions to add)')
- include = True
+ if not apiNameMatch(self.genOpts.apiname, ei.elem.get('supported')):
+ self.gen.logMsg('diag', 'NOT including extension',
+ extName, '(matches explicitly requested, but does not match the \'supported\' attribute)')
+ include = False
+ else:
+ self.gen.logMsg('diag', 'Including extension',
+ extName, '(matches explicitly requested extensions to add)')
+ include = True
# Remove extensions if the name matches the regexp specified
# in generator options. This allows forcing removal of
# extensions from an interface even if they're tagged that